--- ./bin/yum.py.orig	2006-12-05 09:33:35.000000000 +0100
+++ ./bin/yum.py	2007-06-20 16:22:40.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!@@PYTHON@@
 import sys
 try:
     import yum
@@ -23,7 +23,7 @@
 """ % (sys.exc_value, sys.version)
     sys.exit(1)
 
-sys.path.insert(0, '/usr/share/yum-cli')
+sys.path.insert(0, '@@PREFIX@@/share/yum-cli')
 try:
     import yummain
     yummain.main(sys.argv[1:])
--- bin/yum-updatesd.py.orig	2007-07-25 17:05:44.000000000 +0200
+++ bin/yum-updatesd.py	2007-08-28 17:16:06.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!@@PYTHON@@
 import sys, os
 import optparse
 
@@ -16,7 +16,7 @@
     os.dup2(fd, 2)
     os.close(fd)
 
-sys.path.insert(0, '/usr/share/yum-cli')
+sys.path.insert(0, '@@PREFIX@@/share/yum-cli')
 try:
     import yumupd
     yumupd.main(options)
--- ./callback.py.orig	2007-02-03 20:49:32.000000000 +0100
+++ ./callback.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!@@PYTHON@@ -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
    yumupd.main(options)
--- ./docs/Makefile.orig	2006-11-14 07:15:47.000000000 +0100
+++ ./docs/Makefile	2007-06-20 16:26:25.000000000 +0200
@@ -6,10 +6,10 @@
 	rm -fr epydoc
 
 install:
-	mkdir -p $(DESTDIR)/usr/share/man/man5
-	mkdir -p $(DESTDIR)/usr/share/man/man8
-	install -m 644 yum.8 $(DESTDIR)/usr/share/man/man8/yum.8
-	install -m 644 yum-shell.8 $(DESTDIR)/usr/share/man/man8/yum-shell.8
-	install -m 644 yum.conf.5 $(DESTDIR)/usr/share/man/man5/yum.conf.5
-	install -m 644 yum-updatesd.8 $(DESTDIR)/usr/share/man/man8/yum-updatesd.8
-	install -m 644 yum-updatesd.conf.5 $(DESTDIR)/usr/share/man/man5/yum-updatesd.conf.5
+	mkdir -p $(DESTDIR)@@PREFIX@@/share/man/man5
+	mkdir -p $(DESTDIR)@@PREFIX@@/share/man/man8
+	install -m 644 yum.8 $(DESTDIR)@@PREFIX@@/share/man/man8/yum.8
+	install -m 644 yum-shell.8 $(DESTDIR)@@PREFIX@@/share/man/man8/yum-shell.8
+	install -m 644 yum.conf.5 $(DESTDIR)@@PREFIX@@/share/man/man5/yum.conf.5
+	install -m 644 yum-updatesd.8 $(DESTDIR)@@PREFIX@@/share/man/man8/yum-updatesd.8
+	install -m 644 yum-updatesd.conf.5 $(DESTDIR)@@PREFIX@@/share/man/man5/yum-updatesd.conf.5
--- ./etc/Makefile.orig	2007-01-29 17:14:59.000000000 +0100
+++ ./etc/Makefile	2007-06-20 16:26:25.000000000 +0200
@@ -1,4 +1,4 @@
-YUMETC=$(DESTDIR)/etc/yum
+YUMETC=$(DESTDIR)@@PREFIX@@/etc/yum
 
 all:
 	echo "Nothing to do"
@@ -7,32 +7,32 @@
 	rm -f *.pyc *.pyo *~
 
 install:
-	mkdir -p $(DESTDIR)/etc/yum/
-	mkdir -p $(DESTDIR)/etc/yum/protected.d
-	mkdir -p $(DESTDIR)/etc/yum/repos.d
-	mkdir -p $(DESTDIR)/etc/yum/vars
+	mkdir -p $(DESTDIR)@@PREFIX@@/etc/yum/
+	mkdir -p $(DESTDIR)@@PREFIX@@/etc/yum/protected.d
+	mkdir -p $(DESTDIR)@@PREFIX@@/etc/yum/repos.d
+	mkdir -p $(DESTDIR)@@PREFIX@@/etc/yum/vars
 
 	install -m 644 yum.conf $(YUMETC)/yum.conf
 
 	install -m 644 version-groups.conf $(YUMETC)/version-groups.conf
 
-	mkdir -p $(DESTDIR)/etc/logrotate.d
-	install -m 644 yum.logrotate $(DESTDIR)/etc/logrotate.d/yum
+	mkdir -p $(DESTDIR)@@PREFIX@@/etc/logrotate.d
+	install -m 644 yum.logrotate $(DESTDIR)@@PREFIX@@/etc/logrotate.d/yum
 
-	mkdir -p $(DESTDIR)/etc/rc.d/init.d
-	install -m 755 yum-updatesd.init $(DESTDIR)/etc/rc.d/init.d/yum-updatesd
+	mkdir -p $(DESTDIR)@@PREFIX@@/etc/rc.d/init.d
+	install -m 755 yum-updatesd.init $(DESTDIR)@@PREFIX@@/etc/rc.d/init.d/yum-updatesd
 
-	mkdir -p $(DESTDIR)/etc/dbus-1/system.d/
-	install -m 755 yum-updatesd-dbus.conf $(DESTDIR)/etc/dbus-1/system.d/yum-updatesd.conf
+	mkdir -p $(DESTDIR)@@PREFIX@@/etc/dbus-1/system.d/
+	install -m 755 yum-updatesd-dbus.conf $(DESTDIR)@@PREFIX@@/etc/dbus-1/system.d/yum-updatesd.conf
 
-	install -m 755 yum-updatesd.conf $(DESTDIR)/etc/yum/yum-updatesd.conf
-
-	mkdir -p $(DESTDIR)/etc/bash_completion.d
-	install -m 644 yum.bash $(DESTDIR)/etc/bash_completion.d
-	mkdir -p $(DESTDIR)/etc/cron.daily
-	mkdir -p $(DESTDIR)/etc/sysconfig/
-	install -D -m 755 0yum.cron $(DESTDIR)/etc/cron.daily/0yum.cron
-	install -D -m 755 yum-cron $(DESTDIR)/etc/rc.d/init.d/yum-cron
+	install -m 755 yum-updatesd.conf $(DESTDIR)@@PREFIX@@/etc/yum/yum-updatesd.conf
+
+	mkdir -p $(DESTDIR)@@PREFIX@@/etc/bash_completion.d
+	install -m 644 yum.bash $(DESTDIR)@@PREFIX@@/etc/bash_completion.d
+	mkdir -p $(DESTDIR)@@PREFIX@@/etc/cron.daily
+	mkdir -p $(DESTDIR)@@PREFIX@@/etc/sysconfig/
+	install -m 755 0yum.cron $(DESTDIR)@@PREFIX@@/etc/cron.daily/0yum.cron
+	install -m 755 yum-cron $(DESTDIR)@@PREFIX@@/etc/rc.d/init.d/yum-cron
-	install -D -m 644 yum-daily.yum $(YUMETC)/yum-daily.yum
-	install -D -m 644 yum-weekly.yum $(YUMETC)/yum-weekly.yum
-	install -D -m 644 yum-cron.sysconf $(DESTDIR)/etc/sysconfig/yum-cron
+	install -m 644 yum-daily.yum $(YUMETC)/yum-daily.yum
+	install -m 644 yum-weekly.yum $(YUMETC)/yum-weekly.yum
+	install -m 644 yum-cron.sysconf $(DESTDIR)@@PREFIX@@/etc/sysconfig/yum-cron
--- ./etc/yum.console.orig	2004-08-31 05:35:46.000000000 +0200
+++ ./etc/yum.console	2007-06-20 16:43:35.000000000 +0200
@@ -1,4 +1,4 @@
 USER=root
-PROGRAM=/usr/sbin/yum
+PROGRAM=@@PREFIX@@/sbin/yum
 GUI=no
 SESSION=true
--- ./etc/yum.logrotate.jbj	2005-08-20 16:27:45.000000000 -0400
+++ ./etc/yum.logrotate	2005-08-20 16:27:55.000000000 -0400
@@ -1,4 +1,4 @@
-/var/log/yum.log {
+@@PREFIX@@/var/log/yum.log {
     missingok
     notifempty
     size 30k
--- ./yum/i18n.py.orig	2008-04-16 09:05:25.000000000 +0200
+++ ./yum/i18n.py	2007-06-20 16:27:22.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/@@PYTHON@@
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- Makefile.orig	2007-08-22 06:10:48.000000000 +0200
+++ Makefile	2007-08-28 16:58:56.000000000 +0200
@@ -22,19 +22,19 @@
 	for d in $(SUBDIRS); do make PYTHON=$(PYTHON) -C $$d; [ $$? = 0 ] || exit 1 ; done
 
 install:
-	mkdir -p $(DESTDIR)/usr/share/yum-cli
+	mkdir -p $(DESTDIR)@@PREFIX@@/share/yum-cli
 	for p in $(PYFILES) ; do \
-		install -m 644 $$p $(DESTDIR)/usr/share/yum-cli/$$p; \
+		install -m 644 $$p $(DESTDIR)@@PREFIX@@/share/yum-cli/$$p; \
 	done
-	mv $(DESTDIR)/usr/share/yum-cli/yum-updatesd.py $(DESTDIR)/usr/share/yum-cli/yumupd.py
-	$(PYTHON) -c "import compileall; compileall.compile_dir('$(DESTDIR)/usr/share/yum-cli', 1, '$(PYDIR)', 1)"
+	mv $(DESTDIR)@@PREFIX@@/share/yum-cli/yum-updatesd.py $(DESTDIR)@@PREFIX@@/share/yum-cli/yumupd.py
+	$(PYTHON) -c "import compileall; compileall.compile_dir('$(DESTDIR)@@PREFIX@@/share/yum-cli', 1, '$(PYDIR)', 1)"
 
-	mkdir -p $(DESTDIR)/usr/bin $(DESTDIR)/usr/sbin
-	install -m 755 bin/yum.py $(DESTDIR)/usr/bin/yum
-	install -m 755 bin/yum-updatesd.py $(DESTDIR)/usr/sbin/yum-updatesd
+	mkdir -p $(DESTDIR)@@PREFIX@@/bin $(DESTDIR)@@PREFIX@@/sbin
+	install -m 755 bin/yum.py $(DESTDIR)@@PREFIX@@/bin/yum
+	install -m 755 bin/yum-updatesd.py $(DESTDIR)@@PREFIX@@/sbin/yum-updatesd
 
-	mkdir -p $(DESTDIR)/var/cache/yum
-	mkdir -p $(DESTDIR)/var/lib/yum
+	mkdir -p $(DESTDIR)@@PREFIX@@/var/cache/yum
+	mkdir -p $(DESTDIR)@@PREFIX@@/var/lib/yum
 
 	for d in $(SUBDIRS); do make PYTHON=$(PYTHON) DESTDIR=`cd $(DESTDIR); pwd` -C $$d install; [ $$? = 0 ] || exit 1; done
 
--- po/Makefile.orig	2008-01-28 20:04:54.000000000 +0100
+++ po/Makefile	2008-04-16 09:13:47.000000000 +0200
@@ -1,7 +1,7 @@
 INSTALL= /usr/bin/install -c
 INSTALL_PROGRAM= ${INSTALL}
 INSTALL_DATA= ${INSTALL} -m 644
-INSTALLNLSDIR=$(DESTDIR)/usr/share/locale
+INSTALLNLSDIR=$(DESTDIR)@@PREFIX@@/share/locale
 top_srcdir = "."
 
 
--- yum-updatesd.py.orig	2007-05-15 14:18:07.000000000 +0200
+++ yum-updatesd.py	2007-06-29 12:34:07.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!@@PYTHON@@ -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -54,10 +54,10 @@
 from yum.update_md import UpdateMetadata
 
 # FIXME: is it really sane to use this from here?
-sys.path.append('/usr/share/yum-cli')
+sys.path.append('@@PREFIX@@/share/yum-cli')
 import callback
 
-config_file = '/etc/yum/yum-updatesd.conf'
+config_file = '@@PREFIX@@/etc/yum/yum-updatesd.conf'
 initial_directory = os.getcwd()
 
 class UpdateEmitter(object):
@@ -238,7 +238,7 @@
 class UDConfig(BaseConfig):
     """Config format for the daemon"""
     run_interval = IntOption(3600)
-    nonroot_workdir = Option("/var/tmp/yum-updatesd")
+    nonroot_workdir = Option("@@PREFIX@@/var/tmp/yum-updatesd")
     emit_via = ListOption(['dbus', 'email', 'syslog'])
     email_to = ListOption(["root"])
     email_from = Option("root")
@@ -250,7 +250,7 @@
     syslog_facility = Option("DAEMON")
     syslog_level = Option("WARN")
     syslog_ident = Option("yum-updatesd")
-    yum_config = Option("/etc/yum/yum.conf")
+    yum_config = Option("@@PREFIX@@/etc/yum/yum.conf")
 
 
 class UpdateBuildTransactionThread(threading.Thread):
--- ./output.py.orig	2007-01-21 21:21:37.000000000 +0100
+++ ./output.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!@@PYTHON@@ -t
 
 """This handles actual output from the cli"""
 
--- ./po/pygettext.py.orig	2004-01-28 08:31:03.000000000 +0100
+++ ./po/pygettext.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!@@PYTHON@@
 # Originally written by Barry Warsaw <bwarsaw@python.org>
 #
 # minimally patched to make it even more xgettext compatible 
--- ./rpmUtils/__init__.py.orig	2006-08-19 21:05:15.000000000 +0200
+++ ./rpmUtils/__init__.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!@@PYTHON@@ -tt
 
 
 class RpmUtilsError(Exception):
--- ./rpmUtils/arch.py.orig	2007-04-27 14:58:04.000000000 +0200
+++ ./rpmUtils/arch.py	2007-06-20 16:30:29.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!@@PYTHON@@
 #
 
 import os
@@ -236,9 +236,9 @@
     return arch
         
 def getCanonArch(skipRpmPlatform = 0):
-    if not skipRpmPlatform and os.access("/etc/rpm/platform", os.R_OK):
+    if not skipRpmPlatform and os.access("@@PREFIX@@/etc/rpm/platform", os.R_OK):
         try:
-            f = open("/etc/rpm/platform", "r")
+            f = open("@@PREFIX@@/etc/rpm/platform", "r")
             line = f.readline()
             f.close()
             (arch, vendor, opersys) = line.split("-", 2)
@@ -247,6 +247,8 @@
             pass
         
     arch = os.uname()[4]
+    if arch == "Power Macintosh":
+        arch = "ppc"
 
     if (len(arch) == 4 and arch[0] == "i" and arch[2:4] == "86"):
         return getCanonX86Arch(arch)
--- ./rpmUtils/miscutils.py.orig	2007-04-08 05:56:54.000000000 +0200
+++ ./rpmUtils/miscutils.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!@@PYTHON@@ -tt
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
--- ./rpmUtils/oldUtils.py.orig	2004-10-15 05:38:37.000000000 +0200
+++ ./rpmUtils/oldUtils.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!@@PYTHON@@ -tt
 
 import rpm
 import types
--- ./rpmUtils/transaction.py.orig	2006-09-03 23:16:34.000000000 +0200
+++ ./rpmUtils/transaction.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!@@PYTHON@@
 
 #
 # Client code for Update Agent
--- ./rpmUtils/updates.py.orig	2007-04-09 05:08:41.000000000 +0200
+++ ./rpmUtils/updates.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!@@PYTHON@@ -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/__init__.py.orig	2007-05-16 22:57:12.000000000 +0200
+++ ./yum/__init__.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!@@PYTHON@@ -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -92,7 +92,7 @@
        you tweak it here, and when yb.conf does it's thing ... it happens. """
 
     def __init__(self):
-        self.fn = '/etc/yum/yum.conf'
+        self.fn = '@@PREFIX@@/etc/yum/yum.conf'
         self.root = '/'
         self.init_plugins = True
         self.plugin_types = (plugins.TYPE_CORE,)
@@ -208,7 +208,7 @@
         self.preconf.init_plugins = False
         self.conf.cache = cache
 
-    def doConfigSetup(self, fn='/etc/yum/yum.conf', root='/', init_plugins=True,
+    def doConfigSetup(self, fn='@@PREFIX@@/etc/yum/yum.conf', root='/', init_plugins=True,
             plugin_types=(plugins.TYPE_CORE,), optparser=None, debuglevel=None,
             errorlevel=None):
         warnings.warn(_('doConfigSetup() will go away in a future version of Yum.\n'),
--- ./utils.py.orig	2007-04-23 18:44:43.000000000 +0200
+++ ./utils.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!@@PYTHON@@ -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- yum/config.py.orig	2008-10-21 05:24:11.000000000 +0200
+++ yum/config.py	2007-08-28 17:01:05.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!@@PYTHON@@ -t
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -614,15 +614,15 @@
 
     distroverpkg = Option('redhat-release')
     installroot = Option('/')
-    config_file_path = Option('/etc/yum/yum.conf')
+    config_file_path = Option('@@PREFIX@@/etc/yum/yum.conf')
     plugins = BoolOption(False)
-    pluginpath = ListOption(['/usr/share/yum-plugins', '/usr/lib/yum-plugins'])
-    pluginconfpath = ListOption(['/etc/yum/pluginconf.d'])
+    pluginpath = ListOption(['@@PREFIX@@/share/yum-plugins', '@@PREFIX@@/lib/yum-plugins'])
+    pluginconfpath = ListOption(['@@PREFIX@@/etc/yum/pluginconf.d'])
     gaftonmode = BoolOption(False)
     syslog_ident = Option()
     syslog_facility = Option('LOG_USER')
     syslog_device = Option('/dev/log')
-    persistdir = Option('/var/lib/yum')
+    persistdir = Option('@@PREFIX@@/var/lib/yum')
     
 class YumConf(StartupConf):
     '''
@@ -633,11 +633,11 @@
     retries = PositiveIntOption(10, names_of_0=["<forever>"])
     recent = IntOption(7, range_min=0)
 
-    cachedir = Option('/var/cache/yum')
+    cachedir = Option('@@PREFIX@@/var/cache/yum')
 
     keepcache = BoolOption(True)
-    logfile = Option('/var/log/yum.log')
-    reposdir = ListOption(['/etc/yum/repos.d', '/etc/yum.repos.d'])
+    logfile = Option('@@PREFIX@@/var/log/yum.log')
+    reposdir = ListOption(['@@PREFIX@@/etc/yum/repos.d', '@@PREFIX@@/etc/yum.repos.d'])
 
     commands = ListOption()
     exclude = ListOption()
--- ./yum/constants.py.orig	2007-04-11 07:20:00.000000000 +0200
+++ ./yum/constants.py	2007-06-20 16:34:44.000000000 +0200
@@ -17,7 +17,7 @@
 """
 
 #Constants
-YUM_PID_FILE = '/var/run/yum.pid'
+YUM_PID_FILE = '@@PREFIX@@/var/run/yum.pid'
 
 #transaction set states
 TS_UPDATE = 10
--- yum/depsolve.py.orig    2007-08-21 19:30:05.000000000 +0200
+++ yum/depsolve.py 2007-08-28 17:03:37.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!@@PYTHON@@ -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/Errors.py.orig	2007-02-03 22:51:00.000000000 +0100
+++ ./yum/Errors.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!@@PYTHON@@ -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/failover.py.orig	2006-12-05 09:33:35.000000000 +0100
+++ ./yum/failover.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!@@PYTHON@@
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/packageSack.py.orig	2007-03-04 22:46:16.000000000 +0100
+++ ./yum/packageSack.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!@@PYTHON@@ -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/packages.py.orig	2007-04-26 00:19:28.000000000 +0200
+++ ./yum/packages.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!@@PYTHON@@ -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/plugins.py.orig	2007-04-26 06:02:51.000000000 +0200
+++ ./yum/plugins.py	2007-06-29 12:42:24.000000000 +0200
@@ -117,10 +117,10 @@
             This should be sequnce containing one or more of the TYPE_...
             constants. If None (the default), all plugins will be loaded.
         @param pluginconfpath: A list of paths to look for plugin configuration
-            files. Defaults to "/etc/yum/pluginconf.d".
+            files. Defaults to "@@PREFIX@@/etc/yum/pluginconf.d".
         '''
         if not pluginconfpath:
-            pluginconfpath = ['/etc/yum/pluginconf.d']
+            pluginconfpath = ['@@PREFIX@@/etc/yum/pluginconf.d']
 
         self.searchpath = searchpath
         self.pluginconfpath = pluginconfpath
--- ./yum/repoMDObject.py.orig	2007-02-07 07:31:31.000000000 +0100
+++ ./yum/repoMDObject.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!@@PYTHON@@ -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/rpmsack.py.orig	2007-04-27 15:16:12.000000000 +0200
+++ ./yum/rpmsack.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!@@PYTHON@@ -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- yum/rpmtrans.py.orig	2007-08-15 19:27:19.000000000 +0200
+++ yum/rpmtrans.py	2007-08-28 17:12:01.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!@@PYTHON@@ -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/repos.py.orig	2007-04-25 20:55:36.000000000 +0200
+++ ./yum/repos.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!@@PYTHON@@ -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/sqlitesack.py.orig	2007-04-25 20:55:36.000000000 +0200
+++ ./yum/sqlitesack.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!@@PYTHON@@ -tt
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
--- ./yum/sqlutils.py.orig	2007-11-29 19:29:42.000000000 +0100
+++ ./yum/sqlutils.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!@@PYTHON@@ -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of version 2 of the GNU General Public License
 # as published by the Free Software Foundation
--- ./yum/update_md.py.orig	2007-05-15 14:18:08.000000000 +0200
+++ ./yum/update_md.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!@@PYTHON@@ -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yumcommands.py.orig	2007-05-15 14:18:07.000000000 +0200
+++ ./yumcommands.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!@@PYTHON@@ -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yummain.py.orig	2007-01-29 17:14:59.000000000 +0100
+++ ./yummain.py	2007-06-19 18:17:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!@@PYTHON@@ -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- yum/callbacks.py.orig	2007-09-12 17:15:45.000000000 +0200
+++ yum/callbacks.py	2007-10-08 13:43:13.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!@@PYTHON@@ -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- yum/metalink.py.orig	2008-10-14 18:12:59.000000000 +0200
+++ yum/metalink.py	2008-11-06 10:53:42.000000000 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!@@PYTHON@@ -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- yum/history.py.orig	2010-06-29 21:56:57.000000000 +0200
+++ yum/history.py	2010-11-26 12:04:04.000000000 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!@@PYTHON@@ -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- yum/pkgtag_db.py.orig	2010-05-06 16:54:46.000000000 +0200
+++ yum/pkgtag_db.py	2010-11-26 12:03:59.000000000 +0100
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!@@PYTHON@@ -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- cli.py.orig 2007-08-15 17:48:03.000000000 +0200
+++ cli.py      2007-08-28 17:08:57.000000000 +0200
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!@@PYTHON@@ -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -1412,10 +1412,10 @@
         if opts.installroot:
             if os.access(opts.installroot+'/'+opts.conffile, os.R_OK):
                 opts.conffile = opts.installroot+'/'+opts.conffile
-            elif opts.conffile == '/etc/yum/yum.conf':
-                # check if /installroot/etc/yum.conf exists.
-                if os.access(opts.installroot+'/etc/yum.conf', os.R_OK):
-                    opts.conffile = opts.installroot+'/etc/yum.conf'         
+            elif opts.conffile == '@@PREFIX@@/etc/yum/yum.conf':
+                # check if /installroot/@@PREFIX@@/etc/yum.conf exists.
+                if os.access(opts.installroot+'@@PREFIX@@/etc/yum.conf', os.R_OK):
+                    opts.conffile = opts.installroot+'@@PREFIX@@/etc/yum.conf'         
             root=opts.installroot
         else:
             root = '/'
@@ -1456,7 +1456,7 @@
                 action="store_true",
                 help=_("run entirely from system cache, don't update cache"))
         group.add_option("-c", "--config", dest="conffile",
-                default='/etc/yum/yum.conf',
+                default='@@PREFIX@@/etc/yum/yum.conf',
                 help=_("config file location"), metavar='[config file]')
         group.add_option("-R", "--randomwait", dest="sleeptime", type='int',
                 default=None,